Crate heatmap_svg

Crate heatmap_svg 

Structs

Heatmap
a representation of our heatmap, all the fields are corresponding settings you can manually create this struct but it is reccomended to be done with Heatmap::new() as it creates a default template, which you can then edit to your liking

Enums

Span
the period over which the heatmap should span over
StartDate
an enum describing the startig point of the heatmap